==> inductiva-0.8.7.tar.gz: inductiva-0.8.7/inductiva/client/models/__init__.py <==
# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from inductiva.client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from inductiva.client.model.autoscale_policy import AutoscalePolicy
from inductiva.client.model.backend_version import BackendVersion
from inductiva.client.model.base_vm_group import BaseVMGroup
from inductiva.client.model.campaign import Campaign
from inductiva.client.model.campaign_full_info import CampaignFullInfo
from inductiva.client.model.campaign_quota import CampaignQuota
from inductiva.client.model.campaign_users_update import CampaignUsersUpdate
from inductiva.client.model.created_user import CreatedUser
from inductiva.client.model.default_machine_group import DefaultMachineGroup
from inductiva.client.model.dynamic_disk_resize_config import DynamicDiskResizeConfig
from inductiva.client.model.executer import Executer
from inductiva.client.model.executer_tracker_api_connection_info import ExecuterTrackerAPIConnectionInfo
from inductiva.client.model.executer_tracker_register_info import ExecuterTrackerRegisterInfo
from inductiva.client.model.executer_tracker_token import ExecuterTrackerToken
from inductiva.client.model.file_download_url import FileDownloadUrl
from inductiva.client.model.file_info import FileInfo
from inductiva.client.model.file_upload_url import FileUploadUrl
from inductiva.client.model.http_validation_error import HTTPValidationError
from inductiva.client.model.machine_group_status import MachineGroupStatus
from inductiva.client.model.machine_group_terminate_reason import MachineGroupTerminateReason
from inductiva.client.model.machine_group_terminate_request import MachineGroupTerminateRequest
from inductiva.client.model.machine_group_type import MachineGroupType
from inductiva.client.model.machine_type import MachineType
from inductiva.client.model.order import Order
from inductiva.client.model.output_archive_info import OutputArchiveInfo
from inductiva.client.model.project import Project
from inductiva.client.model.project_create import ProjectCreate
from inductiva.client.model.provider import Provider
from inductiva.client.model.providers import Providers
from inductiva.client.model.quota import Quota
from inductiva.client.model.quota_scope import QuotaScope
from inductiva.client.model.storage_file_info import StorageFileInfo
from inductiva.client.model.storage_sort_by import StorageSortBy
from inductiva.client.model.task import Task
from inductiva.client.model.task_metric_create import TaskMetricCreate
from inductiva.client.model.task_metrics import TaskMetrics
from inductiva.client.model.task_position_in_queue import TaskPositionInQueue
from inductiva.client.model.task_request import TaskRequest
from inductiva.client.model.task_status import TaskStatus
from inductiva.client.model.task_status_code import TaskStatusCode
from inductiva.client.model.task_submitted_info import TaskSubmittedInfo
from inductiva.client.model.terms_and_conditions import TermsAndConditions
from inductiva.client.model.tier import Tier
from inductiva.client.model.user import User
from inductiva.client.model.user_activity import UserActivity
from inductiva.client.model.user_api_key import UserApiKey
from inductiva.client.model.user_campaign import UserCampaign
from inductiva.client.model.user_computation_trend import UserComputationTrend
from inductiva.client.model.user_costs_over_time import UserCostsOverTime
from inductiva.client.model.user_create import UserCreate
from inductiva.client.model.user_most_used_machine_types_overview import UserMostUsedMachineTypesOverview
from inductiva.client.model.user_most_used_simulators_overview import UserMostUsedSimulatorsOverview
from inductiva.client.model.user_task_status_overview import UserTaskStatusOverview
from inductiva.client.model.user_tasks_overview import UserTasksOverview
from inductiva.client.model.user_update_terms_and_conditions import UserUpdateTermsAndConditions
from inductiva.client.model.vm_group_config import VMGroupConfig
from inductiva.client.model.validation_error import ValidationError
from inductiva.client.model.version_comparison_result import VersionComparisonResult

==> inductiva-0.9.0.tar.gz: inductiva-0.9.0/inductiva/client/models/__init__.py <==
# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from inductiva.client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from inductiva.client.model.autoscale_policy import AutoscalePolicy
from inductiva.client.model.backend_version import BackendVersion
from inductiva.client.model.base_vm_group import BaseVMGroup
from inductiva.client.model.campaign_create import CampaignCreate
from inductiva.client.model.campaign_full_info import CampaignFullInfo
from inductiva.client.model.campaign_quota import CampaignQuota
from inductiva.client.model.campaign_quota_detail import CampaignQuotaDetail
from inductiva.client.model.campaign_users_update import CampaignUsersUpdate
from inductiva.client.model.capability import Capability
from inductiva.client.model.created_user import CreatedUser
from inductiva.client.model.dynamic_disk_resize_config import DynamicDiskResizeConfig
from inductiva.client.model.executer import Executer
from inductiva.client.model.executer_tracker_api_connection_info import ExecuterTrackerAPIConnectionInfo
from inductiva.client.model.executer_tracker_register_info import ExecuterTrackerRegisterInfo
from inductiva.client.model.executer_tracker_token import ExecuterTrackerToken
from inductiva.client.model.file_download_url import FileDownloadUrl
from inductiva.client.model.file_info import FileInfo
from inductiva.client.model.file_upload_url import FileUploadUrl
from inductiva.client.model.http_validation_error import HTTPValidationError
from inductiva.client.model.machine_group_status import MachineGroupStatus
from inductiva.client.model.machine_group_terminate_reason import MachineGroupTerminateReason
from inductiva.client.model.machine_group_terminate_request import MachineGroupTerminateRequest
from inductiva.client.model.machine_group_type import MachineGroupType
from inductiva.client.model.machine_type import MachineType
from inductiva.client.model.order import Order
from inductiva.client.model.output_archive_info import OutputArchiveInfo
from inductiva.client.model.project import Project
from inductiva.client.model.project_create import ProjectCreate
from inductiva.client.model.provider import Provider
from inductiva.client.model.providers import Providers
from inductiva.client.model.quota import Quota
from inductiva.client.model.quota_scope import QuotaScope
from inductiva.client.model.storage_file_info import StorageFileInfo
from inductiva.client.model.storage_sort_by import StorageSortBy
from inductiva.client.model.task import Task
from inductiva.client.model.task_metric_create import TaskMetricCreate
from inductiva.client.model.task_metrics import TaskMetrics
from inductiva.client.model.task_position_in_queue import TaskPositionInQueue
from inductiva.client.model.task_request import TaskRequest
from inductiva.client.model.task_status import TaskStatus
from inductiva.client.model.task_status_code import TaskStatusCode
from inductiva.client.model.task_submitted_info import TaskSubmittedInfo
from inductiva.client.model.terms_and_conditions import TermsAndConditions
from inductiva.client.model.tier_full_info import TierFullInfo
from inductiva.client.model.tier_quota_detail import TierQuotaDetail
from inductiva.client.model.update_capabilities_actions import UpdateCapabilitiesActions
from inductiva.client.model.update_capabilities_request import UpdateCapabilitiesRequest
from inductiva.client.model.user import User
from inductiva.client.model.user_activity import UserActivity
from inductiva.client.model.user_api_key import UserApiKey
from inductiva.client.model.user_campaign import UserCampaign
from inductiva.client.model.user_computation_trend import UserComputationTrend
from inductiva.client.model.user_costs_over_time import UserCostsOverTime
from inductiva.client.model.user_create import UserCreate
from inductiva.client.model.user_credits import UserCredits
from inductiva.client.model.user_detail import UserDetail
from inductiva.client.model.user_most_used_machine_types_overview import UserMostUsedMachineTypesOverview
from inductiva.client.model.user_most_used_simulators_overview import UserMostUsedSimulatorsOverview
from inductiva.client.model.user_task_status_overview import UserTaskStatusOverview
from inductiva.client.model.user_tasks_overview import UserTasksOverview
from inductiva.client.model.user_tier_credits import UserTierCredits
from inductiva.client.model.user_tier_update import UserTierUpdate
from inductiva.client.model.user_update_terms_and_conditions import UserUpdateTermsAndConditions
from inductiva.client.model.vm_group_config import VMGroupConfig
from inductiva.client.model.validation_error import ValidationError
from inductiva.client.model.version_comparison_result import VersionComparisonResult
